@@ -12,5 +12,4 @@
    See the License for the specific language governing permissions and
    limitations under the License.
 """
-
-import flaskstarter.flaskstart_cli
+__version__ = '0.4.1'
